function [Z,Zdr,R,D0,Adp,Kdp,Rhohv,LWC,Re,Rc,Dm,Sigm,Ahh]= calc_Xband(D,Nd)

% [Z,Zdr,R,D0,Adp,Kdp,Rhohv,LWC,Re,Rc,Dm,Sigm,Ahh]= calc_Xband(Nd)
% Given DSD, calculate the X-band parameters (R,D0,Z,Zdr,Adp,Kdp,Rhohv,...)
% this is based on X band (3 cm)
% This code is for 41 bins [0.1,0.3,0.5,...8.1], D should be at least 0.1 mm spaced
% Unit: Z(dBZ), Zdr(dB), R(mm/h), D0(mm), Adp(dB/km), Kdp(deg/km)...
% Rhohv, LWC(g/m^3), Re(g/m^3/s), Rc(g/m^3/s), Dm(mm), Sigm(mm), Ahh(dB/km)

fort18=load('Xband93_SCTT_RAIN.dat');
% fort18 is the scattering amplitude data for D = [0.1:0.1:10]; 
% here D should include bins which space 0.2 mm. i.e. [0.1,0.3,0.5,...];
d=D(:);
nd=Nd(:);
len=length(Nd);
dd=d(2)-d(1);
row=[1:2:len*2];
%fort18=fort18(row,:);
% backward scattering 
dT=fort18(:,1);
bar=fort18(:,2).*1;   % *1000 is to convert to mm
bai=fort18(:,3).*1;
bbr=fort18(:,4).*1;
bbi=fort18(:,5).*1;
% foreward scattering
far=fort18(:,6).*1;
fai=fort18(:,7).*1;
fbr=fort18(:,8).*1;
fbi=fort18(:,9).*1;
%%%%
bam=abs(bar+i.*bai);
bbm=abs(bbr+i.*bbi);
fam=abs(far+i.*fai);
fbm=abs(fbr+i.*fbi);
faa=angle(fbr+i.*fai).*180./pi;
fba=angle(fbr+i.*fbi).*180./pi;
baa=angle(bar+i.*bai).*180./pi;
bba=angle(-bbr-i.*bbi).*180./pi;

c0=-0.1021; c1=4.932; c2=-0.9551; c3=0.07934; c4=-0.002362; 
v=c0+c1.*d+c2.*d.^2+c3.*d.^3+c4.*d.^4;    %% terminal velocity of Ed. 
fh=bam;
fv=bbm;
fhc=bar+i.*bai;
fvc=bbr+i.*bbi;
fd=far-fbr;
ah=fai;
av=fbi;
%%%%
phi=0*pi/180;
epr=55.49+j*37.84;  %% for X-band
K2=abs((epr-1)/(epr+2))^2;
wave=32.3;
fhh2=pi^4*K2/4/wave^4;
kx=2*pi/wave;
%%%%
fh=interp1(dT,fh,d);
fv=interp1(dT,fv,d);
fhc=interp1(dT,fhc,d);
fvc=interp1(dT,fvc,d);
fd=interp1(dT,fd,d);
ah=interp1(dT,ah,d);
av=interp1(dT,av,d);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% calculate rain microphysical characteristics
Fh2=sum(fh.^2.*nd).*dd;
Fv2=sum(fv.^2.*nd).*dd;
Fhv=sum(conj(fhc).*fvc.*nd).*dd;
Fd=sum(fd.*nd).*dd;
Ah=sum(ah.*nd).*dd;
Av=sum(av.*nd).*dd;
ath=(1-2*phi^2)*Ah+2*phi^2*sqrt(Ah*Av);
atv=(1-2*phi^2)*Av+2*phi^2*sqrt(Ah*Av);

temp1=((1-2*phi^2)*fh.^2+2*phi^2.*fhc.*fvc).*nd*dd; %% revise the fhc, fvc
temp2=((1-2*phi^2)*fv.^2+2*phi^2.*fhc.*fvc).*nd*dd; %% revise the fhc, fvc
temp3=wave*(1-2*phi^2)*fd.*nd*dd*180/pi/1e+3;
zh=abs(sum(temp1,1)')./fhh2;  %% revise the fhc, fvc
zv=abs(sum(temp2,1)')./fhh2;  %% revise the fhc, fvc

Z=10*log10(zh);
Zdr=10*log10(zh./zv);
Kdp=sum(temp3,1)';
Rhohv=abs(Fhv)./sqrt(Fh2.*Fv2);  %% revise the Rhohv
Adp=4.343e-3*2*wave*(ath-atv);    %% unit (dB/km)
Ahh=4.343e-3*2*wave*ath;    %% unit (dB/km)

%%%%
D3=sum(nd.*d.^3*dd);   % moment 3
D4=sum(nd.*d.^4*dd);
R=sum(pi/6.0*3.6e-3.*v.*d.^3.*nd*dd);
LWC=1e-3*pi/6.*D3;
%%%% estimate the spectrum width     
Dm=D4/D3;
sigm2=sum((d-Dm).^2.*nd.*d.^3*dd);
Sigm=(sigm2./D3).^(0.5);
%%%% calculate the mean diameter D0
D0=Dm;%D0find(d,nd);
%%%%
%%%% calculate the Re, Rc, Vtm
temp=3.55e-7.*nd.*d.^(8/5).*dd;
Re=sum(temp,1)';

temp=pi/4*(1e-6).*nd.*(d.^2).*v.*dd;  %% use fitted Vt
Rc=sum(temp,1)';    %% based on fitted Vt

% temp=nd.*d.^3.*v.*dd;  %% use measured Vt
% temp1=nd.*d.^3.*dd;
% Vtm=sum(temp,1)'./sum(temp1,1)';    %% based on fitted Vt
